==> ui5__webcomponents-icons-1.0.2.jar: META-INF/resources/webjars/ui5__webcomponents-icons/1.0.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.0.2](https://github.com/SAP/ui5-webcomponents/compare/v1.0.1...v1.0.2) (2021-11-29)


### Bug Fixes

* prevent runtime error on malformed custom theme object ([#4375](https://github.com/SAP/ui5-webcomponents/issues/4375)) ([dd10d7c](https://github.com/SAP/ui5-webcomponents/commit/dd10d7c))





## [1.0.1](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0...v1.0.1) (2021-11-10)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.16...v1.0.0) (2021-11-10)


**Note:** Version bump only for package @ui5/webcomponents-icons
```





# [1.0.0-rc.16](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.15...v1.0.0-rc.16) (2021-11-09)


### Features

* **icons:** introduce SAP-icons5.0 ([#4244](https://github.com/SAP/ui5-webcomponents/issues/4244)) ([c0a226e](https://github.com/SAP/ui5-webcomponents/commit/c0a226e))


### BREAKING CHANGES

* The icons SVG imports are changed. If you previously had
```js
import "@ui5/webcomponents-icons/dist/accept.svg";
```
 you have to import the SVGs from the **v4/**  or the **v5/** directory:
```js
import "@ui5/webcomponents-icons/dist/v4/accept.svg"; //  for SAPIcons4.0
import "@ui5/webcomponents-icons/dist/v5/accept.svg"; // for SAPIcons5.0
```





# [1.0.0-rc.15](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.14...v1.0.0-rc.15) (2021-07-23)


**Note:** Version bump only for package @ui5/webcomponents-icons-tnt





 [1.0.0-rc.14](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.13...v1.0.0-rc.14) (2021-04-01)


**Note:** Version bump only for package @ui5/webcomponents-icons-tnt


# [1.0.0-rc.13(https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.12...v1.0.0-rc.13) (2021-03-26)


### Features

* **icons:** add new icons ([#3024](https://github.com/SAP/ui5-webcomponents/issues/3024)) ([8da6502](https://github.com/SAP/ui5-webcomponents/commit/8da6502))




# [1.0.0-rc.12](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.11...v1.0.0-rc.12) (2021-02-18)


### Bug Fixes

* **ui5-icon:** ui5-icon i18n works for all packages ([#2816](https://github.com/SAP/ui5-webcomponents/issues/2816)) ([91e16a1](https://github.com/SAP/ui5-webcomponents/commit/91e16a1))




# [1.0.0-rc.11](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.10...v1.0.0-rc.11) (2020-12-21)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.10](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.9...v1.0.0-rc.10) (2020-11-12)


### Bug Fixes

* **icons:** Fix text-formatting icon ([#2326](https://github.com/SAP/ui5-webcomponents/issues/2326)) ([d69fbcb](https://github.com/SAP/ui5-webcomponents/commit/d69fbcb))


### Features

* **icons:** update icons from latest icon font ([#2397](https://github.com/SAP/ui5-webcomponents/issues/2397)) ([11d3bbc](https://github.com/SAP/ui5-webcomponents/commit/11d3bbc))





# [1.0.0-rc.9](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.8...v1.0.0-rc.9) (2020-10-08)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.8](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.7...v1.0.0-rc.8) (2020-07-30)


### Bug Fixes

* **icons:** overflow icon is now centered ([#1777](https://github.com/SAP/ui5-webcomponents/issues/1777)) ([36d0eca](https://github.com/SAP/ui5-webcomponents/commit/36d0eca))


### Features

* **framework:** Make icons RTL aware ([#1833](https://github.com/SAP/ui5-webcomponents/issues/1833)) ([29a991f](https://github.com/SAP/ui5-webcomponents/commit/29a991f)), closes [#1831](https://github.com/SAP/ui5-webcomponents/issues/1831)





# [1.0.0-rc.7](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.6...v1.0.0-rc.7) (2020-04-30)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.6](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.5...v1.0.0-rc.6) (2020-03-27)

**Note:** Version bump only for package @ui5/webcomponents-icons




# [1.0.0-rc.5](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.4...v1.0.0-rc.5) (2019-12-02)

**Note:** Version bump only for package @ui5/webcomponents-icons

==> ui5__webcomponents-icons-1.4.0.jar: META-INF/resources/webjars/ui5__webcomponents-icons/1.4.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [1.4.0](https://github.com/SAP/ui5-webcomponents/compare/v1.3.1...v1.4.0) (2022-05-25)

**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.3.1](https://github.com/SAP/ui5-webcomponents/compare/v1.3.0...v1.3.1) (2022-04-27)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.3.0](https://github.com/SAP/ui5-webcomponents/compare/v1.2.4...v1.3.0) (2022-04-19)


**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.2.4](https://github.com/SAP/ui5-webcomponents/compare/v1.2.3...v1.2.4) (2022-03-30)

**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.2.3](https://github.com/SAP/ui5-webcomponents/compare/v1.2.2...v1.2.3) (2022-03-23)

**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.2.2](https://github.com/SAP/ui5-webcomponents/compare/v1.2.1...v1.2.2) (2022-03-22)

**Note:** Version bump only for package @ui5/webcomponents-icons






## [1.2.1](https://github.com/SAP/ui5-webcomponents/compare/v1.2.0...v1.2.1) (2022-03-02)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.2.0](https://github.com/SAP/ui5-webcomponents/compare/v1.1.2...v1.2.0) (2022-02-28)


### Features

* add and update icons from 4.13 and 5.01 icon fonts  ([#4790](https://github.com/SAP/ui5-webcomponents/issues/4790)) ([a9e88f0](https://github.com/SAP/ui5-webcomponents/commit/a9e88f0))
* **icons:** add `qr-code` icon ([#4645](https://github.com/SAP/ui5-webcomponents/issues/4645)) ([0208103](https://github.com/SAP/ui5-webcomponents/commit/0208103)), closes [#4643](https://github.com/SAP/ui5-webcomponents/issues/4643)





## [1.1.2](https://github.com/SAP/ui5-webcomponents/compare/v1.1.1...v1.1.2) (2022-01-26)

**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.1.1](https://github.com/SAP/ui5-webcomponents/compare/v1.1.0...v1.1.1) (2022-01-24)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.1.0](https://github.com/SAP/ui5-webcomponents/compare/v1.0.2...v1.1.0) (2022-01-21)

**Note:** Version bump only for package @ui5/webcomponents-icons





## [1.0.2](https://github.com/SAP/ui5-webcomponents/compare/v1.0.1...v1.0.2) (2021-11-29)


### Bug Fixes

* prevent runtime error on malformed custom theme object ([#4375](https://github.com/SAP/ui5-webcomponents/issues/4375)) ([dd10d7c](https://github.com/SAP/ui5-webcomponents/commit/dd10d7c))





## [1.0.1](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0...v1.0.1) (2021-11-10)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.16...v1.0.0) (2021-11-10)


**Note:** Version bump only for package @ui5/webcomponents-icons
```





# [1.0.0-rc.16](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.15...v1.0.0-rc.16) (2021-11-09)


### Features

* **icons:** introduce SAP-icons5.0 ([#4244](https://github.com/SAP/ui5-webcomponents/issues/4244)) ([c0a226e](https://github.com/SAP/ui5-webcomponents/commit/c0a226e))


### BREAKING CHANGES

* The icons SVG imports are changed. If you previously had
```js
import "@ui5/webcomponents-icons/dist/accept.svg";
```
 you have to import the SVGs from the **v4/**  or the **v5/** directory:
```js
import "@ui5/webcomponents-icons/dist/v4/accept.svg"; //  for SAPIcons4.0
import "@ui5/webcomponents-icons/dist/v5/accept.svg"; // for SAPIcons5.0
```





# [1.0.0-rc.15](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.14...v1.0.0-rc.15) (2021-07-23)


**Note:** Version bump only for package @ui5/webcomponents-icons-tnt





 [1.0.0-rc.14](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.13...v1.0.0-rc.14) (2021-04-01)


**Note:** Version bump only for package @ui5/webcomponents-icons-tnt


# [1.0.0-rc.13(https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.12...v1.0.0-rc.13) (2021-03-26)


### Features

* **icons:** add new icons ([#3024](https://github.com/SAP/ui5-webcomponents/issues/3024)) ([8da6502](https://github.com/SAP/ui5-webcomponents/commit/8da6502))




# [1.0.0-rc.12](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.11...v1.0.0-rc.12) (2021-02-18)


### Bug Fixes

* **ui5-icon:** ui5-icon i18n works for all packages ([#2816](https://github.com/SAP/ui5-webcomponents/issues/2816)) ([91e16a1](https://github.com/SAP/ui5-webcomponents/commit/91e16a1))




# [1.0.0-rc.11](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.10...v1.0.0-rc.11) (2020-12-21)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.10](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.9...v1.0.0-rc.10) (2020-11-12)


### Bug Fixes

* **icons:** Fix text-formatting icon ([#2326](https://github.com/SAP/ui5-webcomponents/issues/2326)) ([d69fbcb](https://github.com/SAP/ui5-webcomponents/commit/d69fbcb))


### Features

* **icons:** update icons from latest icon font ([#2397](https://github.com/SAP/ui5-webcomponents/issues/2397)) ([11d3bbc](https://github.com/SAP/ui5-webcomponents/commit/11d3bbc))





# [1.0.0-rc.9](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.8...v1.0.0-rc.9) (2020-10-08)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.8](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.7...v1.0.0-rc.8) (2020-07-30)


### Bug Fixes

* **icons:** overflow icon is now centered ([#1777](https://github.com/SAP/ui5-webcomponents/issues/1777)) ([36d0eca](https://github.com/SAP/ui5-webcomponents/commit/36d0eca))


### Features

* **framework:** Make icons RTL aware ([#1833](https://github.com/SAP/ui5-webcomponents/issues/1833)) ([29a991f](https://github.com/SAP/ui5-webcomponents/commit/29a991f)), closes [#1831](https://github.com/SAP/ui5-webcomponents/issues/1831)





# [1.0.0-rc.7](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.6...v1.0.0-rc.7) (2020-04-30)

**Note:** Version bump only for package @ui5/webcomponents-icons





# [1.0.0-rc.6](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.5...v1.0.0-rc.6) (2020-03-27)

**Note:** Version bump only for package @ui5/webcomponents-icons




# [1.0.0-rc.5](https://github.com/SAP/ui5-webcomponents/compare/v1.0.0-rc.4...v1.0.0-rc.5) (2019-12-02)

**Note:** Version bump only for package @ui5/webcomponents-icons
